=========
Reference
=========

Manipulation of strings
-----------------------

.. autoclass:: hanabython.Modules.StringAnsi.StringAnsi
    :members:

.. autofunction:: hanabython.Modules.StringUtils.str_from_iterable

.. autofunction:: hanabython.Modules.StringUtils.title

.. autofunction:: hanabython.Modules.StringUtils.uncolor

.. autoclass:: hanabython.Modules.Colored.Colored
    :members:

Colors
------

.. autoclass:: hanabython.Modules.Color.Color
    :members:

.. autoclass:: hanabython.Modules.ColorMulticolor.ColorMulticolor
    :members:

.. autoclass:: hanabython.Modules.ColorColorless.ColorColorless
    :members:

.. autoclass:: hanabython.Modules.Colors.Colors
    :members:

Configuration
-------------

.. autoclass:: hanabython.Modules.ConfigurationColorContents.ConfigurationColorContents
    :members:

.. autoclass:: hanabython.Modules.ConfigurationDeck.ConfigurationDeck
    :members:

.. autoclass:: hanabython.Modules.ConfigurationEmptyClueRule.ConfigurationEmptyClueRule
    :members:

.. autoclass:: hanabython.Modules.ConfigurationEndRule.ConfigurationEndRule
    :members:

.. autoclass:: hanabython.Modules.ConfigurationHandSize.ConfigurationHandSize
    :members:

.. autoclass:: hanabython.Modules.Configuration.Configuration
    :members:

Clues
-----

.. autoclass:: hanabython.Modules.Clue.Clue
    :members:

Cards
-----

.. autoclass:: hanabython.Modules.Card.Card
    :members:

.. autoclass:: hanabython.Modules.CardPublic.CardPublic
    :members:

Hands
-----

.. autoclass:: hanabython.Modules.Hand.Hand
    :members:

.. autoclass:: hanabython.Modules.HandPublic.HandPublic
    :members:

Draw Pile
---------

.. autoclass:: hanabython.Modules.DrawPile.DrawPile
    :members:

.. autoclass:: hanabython.Modules.DrawPilePublic.DrawPilePublic
    :members:

Discard Pile
------------

.. autoclass:: hanabython.Modules.DiscardPile.DiscardPile
    :members:

Board
-----

.. autoclass:: hanabython.Modules.Board.Board
    :members:

Actions
-------

.. autoclass:: hanabython.Modules.Action.Action
    :members:

.. autoclass:: hanabython.Modules.ActionDiscard.ActionDiscard
    :members:

.. autoclass:: hanabython.Modules.ActionPlay.ActionPlay
    :members:

.. autoclass:: hanabython.Modules.ActionClue.ActionClue
    :members:

.. autoclass:: hanabython.Modules.ActionForfeit.ActionForfeit
    :members:

Players
-------

.. autoclass:: hanabython.Modules.Player.Player
    :members:

.. autoclass:: hanabython.Modules.PlayerPuppet.PlayerPuppet
    :members:

.. autoclass:: hanabython.Modules.PlayerBase.PlayerBase
    :members:

.. autoclass:: hanabython.Modules.PlayerHumanText.PlayerHumanText
    :members:

Game
----

.. autoclass:: hanabython.Modules.Game.Game
    :members:

